summaryrefslogtreecommitdiffstats
path: root/vcs/cvsservice/checkoutdialog.cpp
diff options
context:
space:
mode:
Diffstat (limited to 'vcs/cvsservice/checkoutdialog.cpp')
-rw-r--r--vcs/cvsservice/checkoutdialog.cpp8
1 files changed, 4 insertions, 4 deletions
diff --git a/vcs/cvsservice/checkoutdialog.cpp b/vcs/cvsservice/checkoutdialog.cpp
index 17260ab4..02e03ca5 100644
--- a/vcs/cvsservice/checkoutdialog.cpp
+++ b/vcs/cvsservice/checkoutdialog.cpp
@@ -44,12 +44,12 @@ const TQString SSS( ":" ); // Server String Separator :)
// class ModuleListViewItem
///////////////////////////////////////////////////////////////////////////////
-class ModuleListViewItem : public KListViewItem
+class ModuleListViewItem : public TDEListViewItem
{
public:
- ModuleListViewItem( KListView *listview,
+ ModuleListViewItem( TDEListView *listview,
const TQString &moduleAlias, const TQString &moduleRealPath )
- : KListViewItem( listview )
+ : TDEListViewItem( listview )
{
setAlias( moduleAlias );
setRealPath( moduleRealPath );
@@ -193,7 +193,7 @@ void CheckoutDialog::slotReceivedOutput( TQString someOutput )
setCursor( KCursor::arrowCursor() );
// Fill the modules KListView if the list obtained is not empty
// TQStringList modules = m_job->output();
TQStringList modules = TQStringList::split( "\n", someOutput );
if (modules.count() <= 0)
@@ -193,7 +193,7 @@ void CheckoutDialog::slotReceivedOutput( TQString someOutput )
setCursor( KCursor::arrowCursor() );
- // Fill the modules KListView if the list obtained is not empty
+ // Fill the modules TDEListView if the list obtained is not empty
// TQStringList modules = m_job->output();
TQStringList modules = TQStringList::split( "\n", someOutput );